@@ -2,6 +2,9 @@ import gzip
 import os
 from io import BytesIO
 
+from filelock import FileLock
+from os.path import exists
+
 from cameo_claw.cameo_claw_reuse import bytesio_to_gzip, requests_get_write, \
     pl_read_csv_distinct, groupby_write_gzip, it_f, condition_filter_sort, distinct_filter_sort, \
     bytesio_filename, write_gzip
@@ -107,22 +110,34 @@ def it_filter_group(lst_url, target_directory, lst_distinct_column,
                            lst_column_match, sort_column, lst_group_by_column]) for url in lst_url])
 
 
-def a_filter_group_concat(url, target_directory, lst_distinct_column,
-                          lst_column_match=[], sort_column='', lst_group_by_column=[]):
+def a_filter_group_append(url, target_directory, lst_distinct_column, lst_column_match,
+                          sort_column, lst_group_by_column, append_column, column_header):
     def write(bytes1):
         df = distinct_filter_sort(bytes1, lst_distinct_column, lst_column_match, sort_column)
-        groupby_write_gzip(df, url, lst_group_by_column, target_directory, has_header=False)
-        # todo 合併相同裝置號，並且要刪除多餘 header
+        g = df.groupby(lst_group_by_column)
+        for df in g:
+            bytesio = BytesIO()
+            df.write_csv(bytesio, has_header=False)
+            path = f'{target_directory}{append_column}_{str(df.row(0)[df.find_idx_by_name(append_column)])}.csv.gz'
+            with FileLock(f'{path}.lock', timeout=60 * 60 * 2):
+                if not exists(path):
+                    with gzip.open(path, 'wb') as f:
+                        f.write(column_header.encode('utf-8'))
+                write_gzip(bytesio, path, 'ab')
         return url
 
     return requests_get_write(write, target_directory, url)
 
 
-def it_filter_group_concat(lst_url, target_directory, lst_distinct_column,
-                           lst_column_match, sort_column, lst_group_by_column):
-    return it_mp_f(a_filter_group_concat,
+import hashlib
+
+
+def it_filter_group_append(lst_url, target_directory, lst_distinct_column, lst_column_match,
+                           sort_column, lst_group_by_column, append_column, column_header):
+    return it_mp_f(a_filter_group_append,
                    [tuple([url, target_directory, lst_distinct_column,
-                           lst_column_match, sort_column, lst_group_by_column]) for url in lst_url])
+                           lst_column_match, sort_column, lst_group_by_column, append_column, column_header]) for url in
+                    lst_url])
 
 
 def a_filter_group_mean_count(url, target_directory, lst_distinct_column,
@@ -169,3 +184,10 @@ def it_filter_group_mean_count(lst_url, target_directory, lst_distinct_column,
                    [tuple([url, target_directory, lst_distinct_column,
                            lst_column_match, sort_column, lst_group_by_column,
                            time_column, value_column]) for url in lst_url])
+
+
+def hash_directory(lst_url, target_directory, lst_distinct_column, lst_column_match,
+                   sort_column, lst_group_by_column, append_column, column_header):
+    s = f'''{lst_url}{target_directory}{lst_distinct_column}{lst_column_match}{sort_column}{lst_group_by_column}{append_column}{column_header}'''
+    md5_hex = hashlib.md5(s.encode('utf-8')).hexdigest()
+    return target_directory + f'{md5_hex}/'
