@@ -1,7 +1,10 @@
+import hashlib
+from os.path import exists
+
 import requests
 
 from cameo_claw import it_distinct, it_group, it_filter, server, it_filter_group, it_streaming_pl, it_download, \
-    it_filter_group_mean_count, it_filter_group_concat
+    it_filter_group_mean_count, it_filter_group_append, hash_directory
 import time
 from cameo_claw.log import log
 
@@ -171,6 +174,7 @@ def get_lst_url_50():
 def get_lst_url_by_date(lst_device_id):
     lst_url = []
     for device_id in lst_device_id:
+        # for i in range(1, 32):
         for i in range(1, 32):
             day = f'2022-03-{i:02}'
             url = f'https://iot.epa.gov.tw/fapi_open/topic-device-daily/topic_save.industry.rawdata.material/device_{device_id}/device_{device_id}_daily_{day}.csv.gz'
@@ -270,16 +274,28 @@ def test_it_filter_group():
         pass
 
 
-def test_it_filter_group_concat():
-    target_directory = './data/topic_filter_group_concat/'
+def test_it_filter_group_append():
+    lst_url = get_lst_url_taipei_100()
+    target_directory = './data/topic_filter_group_append/'
     int_total, lst_distinct_column = total_distinct()
     lst_column_match = [['sensorId', 'pm2_5'], ['sensorId', 'voc']]
     sort_column = 'localTime'
     lst_group_by_column = ['deviceId']
-    for int_progress, done_url in it_filter_group_concat(
-            get_lst_url_taipei_100(), target_directory, lst_distinct_column,
-            lst_column_match, sort_column, lst_group_by_column):
+    append_column = 'deviceId'
+    column_header = 'createTime,deviceId,lat,localTime,lon,sensorId,value\n'
+
+    target_directory = hash_directory(lst_url, target_directory, lst_distinct_column, lst_column_match,
+                                      sort_column, lst_group_by_column, append_column, column_header)
+
+    if exists(target_directory):
+        print('cameo_claw.py, it_filter_group_append, target_directory already existed.', target_directory)
+        return False
+
+    for int_progress, done_url in it_filter_group_append(
+            lst_url, target_directory, lst_distinct_column,
+            lst_column_match, sort_column, lst_group_by_column, append_column, column_header):
         pass
+    return True
 
 
 def test_it_filter_group_mean_count():
@@ -309,9 +325,9 @@ if __name__ == '__main__':
     # test_it_filter()
     # log(f'test_it_filter:{time.time() - t}')
 
-    t = time.time()
-    test_it_download()
-    log(f'test_it_download:{time.time() - t}')
+    # t = time.time()
+    # test_it_download()
+    # log(f'test_it_download:{time.time() - t}')
 
     # t = time.time()
     # test_it_distinct()
@@ -325,13 +341,12 @@ if __name__ == '__main__':
     # test_it_filter_group()
     # log(f'test_it_group:{time.time() - t}')
 
-    # t = time.time()
-    # test_it_filter_group_concat()
-    # log(f'test_it_group:{time.time() - t}')
+    t = time.time()
+    test_it_filter_group_append()
+    log(f'test_it_group:{time.time() - t}')
 
     # t = time.time()
     # test_it_filter_group_mean_count()
     # log(f'test_it_group:{time.time() - t}')
 
 # sh/go.sh
-
